@@ -1,5 +1,7 @@
 predict.sltime <-function(object, newdata=NULL, newtimes=NULL, ...){
 
+
+
   M<-length(object$methods)
 
   Fit<- vector("list", M+1)
@@ -8,8 +10,13 @@ predict.sltime <-function(object, newdata=NULL, newtimes=NULL, ...){
     for (i in 1:M) { Fit[[i]] <- (predict(object$models[[i]]))$predictions }
     Fit[[M+1]]<-object$predictions[,-1]
     time.pred<-object$times[-1]
-    } else {
-    time.pred<-newtimes
+  }else {
+    
+    newtimes<-sort(newtimes)
+    
+    if(! is.null(newtimes)) {time.pred <- newtimes}
+    
+    if(!is.null(newtimes) & 0 %in% newtimes) {time.pred <- newtimes[which(newtimes!=0)]}
 
     if(is.null(newtimes)) {time.pred <- object$times[-1]}
 
@@ -21,6 +28,17 @@ predict.sltime <-function(object, newdata=NULL, newtimes=NULL, ...){
 
     weighted_matrices <- mapply(function(mat, weight) mat * weight, Fit[-(M+1)], w.sl, SIMPLIFY = FALSE)
     Fit[[M+1]] <- Reduce("+", weighted_matrices)
+    
+    if(!is.null(newtimes) & 0 %in% newtimes) {
+      Fit<-lapply(Fit, function(mat){
+        mat=cbind(rep(1,nrow(mat)),mat)
+        return(mat)
+      })
+    }
+    
+
+
+
 
   }
 
@@ -32,6 +50,3 @@ predict.sltime <-function(object, newdata=NULL, newtimes=NULL, ...){
   return(list(predictions=Fit,
               times=time.pred))
 }
-
-
-
